@@ -71,10 +71,14 @@ class Newton:
         else:
             return res.text
 
-    def get_task(self, task_id: str=None):
+    def get_task(self, task_id: str=None, trail: bool=False):
         api_url = f"{self.api_base}/task/{task_id}"
 
-        res = requests.get(api_url, headers=self.__headers)       
+        params = {}
+        if trail == True:    
+            params["full_trail"] = "true" 
+
+        res = requests.get(api_url,params,headers=self.__headers)       
         if res.ok:
             return res.json()
         else:
@@ -89,7 +93,7 @@ class Newton:
         else:
             return res.text
 
-    def get_tasks(self, project_id, task_id: str=None, file_name: str=None, file_type: str=None, trail: bool=False):
+    def get_tasks(self, project_id, task_id: str=None, file_name: str=None, file_type: str=None):
         api_url = f"{self.api_base}/task/list/{project_id}"
 
         params = {}
@@ -99,8 +103,8 @@ class Newton:
             params["file_name"] = file_name
         if file_type is not None:
             params["file_type"] = file_type
-        if trail == True:    
-            params["trail"] = "true" 
+        # if trail == True:    
+        #     params["trail"] = "true" 
 
         res = requests.get(api_url, params=params, headers=self.__headers)
         if res.ok:
